@@ -1,5 +1,5 @@
-import tetr_face_coord
-import tetr_face_COM_coord
+from .tetr_face_coord import tetr_face_coord
+from .tetr_face_COM_coord import tetr_face_COM_coord
 
 
 def tetr_face_COM_list_gen(radius: float):
